@@ -5,12 +5,12 @@
     <name>mxselectsound</name>
     <message>
         <location filename="../mxselectsound.ui" line="14"/>
-        <location filename="../mxselectsound.cpp" line="46"/>
-        <location filename="../mxselectsound.cpp" line="82"/>
-        <location filename="../mxselectsound.cpp" line="140"/>
-        <location filename="../mxselectsound.cpp" line="152"/>
-        <location filename="../mxselectsound.cpp" line="186"/>
-        <location filename="../mxselectsound.cpp" line="195"/>
+        <location filename="../mxselectsound.cpp" line="47"/>
+        <location filename="../mxselectsound.cpp" line="77"/>
+        <location filename="../mxselectsound.cpp" line="135"/>
+        <location filename="../mxselectsound.cpp" line="147"/>
+        <location filename="../mxselectsound.cpp" line="181"/>
+        <location filename="../mxselectsound.cpp" line="190"/>
         <source>MX Select Sound</source>
         <translation type="unfinished"></translation>
     </message>
@@ -85,59 +85,59 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mxselectsound.cpp" line="83"/>
+        <location filename="../mxselectsound.cpp" line="78"/>
         <source>No sound cards/devices were found.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mxselectsound.cpp" line="95"/>
-        <location filename="../mxselectsound.cpp" line="109"/>
+        <location filename="../mxselectsound.cpp" line="90"/>
+        <location filename="../mxselectsound.cpp" line="104"/>
         <source>none</source>
         <translation>nincs</translation>
     </message>
     <message>
-        <location filename="../mxselectsound.cpp" line="139"/>
+        <location filename="../mxselectsound.cpp" line="134"/>
         <source>About MX Select Sound</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mxselectsound.cpp" line="140"/>
+        <location filename="../mxselectsound.cpp" line="135"/>
         <source>Version: </source>
         <translation>Verzió:</translation>
     </message>
     <message>
-        <location filename="../mxselectsound.cpp" line="141"/>
+        <location filename="../mxselectsound.cpp" line="136"/>
         <source>Program for selecting the default sound card in MX Linux</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mxselectsound.cpp" line="143"/>
+        <location filename="../mxselectsound.cpp" line="138"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Copyright (c) MX Linux</translation>
     </message>
     <message>
-        <location filename="../mxselectsound.cpp" line="144"/>
-        <location filename="../mxselectsound.cpp" line="152"/>
+        <location filename="../mxselectsound.cpp" line="139"/>
+        <location filename="../mxselectsound.cpp" line="147"/>
         <source>License</source>
         <translation>Liszensz</translation>
     </message>
     <message>
-        <location filename="../mxselectsound.cpp" line="145"/>
+        <location filename="../mxselectsound.cpp" line="140"/>
         <source>Changelog</source>
-        <translation type="unfinished"></translation>
+        <translation>Változásbejegyzés</translation>
     </message>
     <message>
-        <location filename="../mxselectsound.cpp" line="146"/>
+        <location filename="../mxselectsound.cpp" line="141"/>
         <source>Cancel</source>
         <translation>Mégsem</translation>
     </message>
     <message>
-        <location filename="../mxselectsound.cpp" line="161"/>
+        <location filename="../mxselectsound.cpp" line="156"/>
         <source>&amp;Close</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Bezár</translation>
     </message>
     <message>
-        <location filename="../mxselectsound.cpp" line="196"/>
+        <location filename="../mxselectsound.cpp" line="191"/>
         <source>Could not play test sound.</source>
         <translation type="unfinished"></translation>
     </message>
